import { Component, IComponentPropsWithoutRef } from '@clutchd/component';
import * as React from 'react';

/**
 * Type to define the direction prop used by multiple `Layout` components
 */
interface ILayoutWithDirection {
    direction?: "col" | "row";
}
/**
 * Type to define the padding prop used by multiple `Layout` components
 */
interface ILayoutWithPadding {
    padding?: boolean;
}

/**
 * Type to define `Content` element
 */
type IContent = React.ElementRef<typeof Component.main>;
/**
 * Type to define `Content` props
 */
interface IContentProps extends ILayoutWithDirection, ILayoutWithPadding, IComponentPropsWithoutRef<typeof Component.main> {
}
/**
 * `Content` - A layout component designed to contain a page's primary content. Renders as a `main` element
 * @param props `IContentProps` used to render this `Content`
 * @returns `Content` component
 */
declare const Content: React.ForwardRefExoticComponent<IContentProps & React.RefAttributes<HTMLElement>>;

/**
 * Type to define `Footer` element
 */
type IFooter = React.ElementRef<typeof Component.footer>;
/**
 * Type to define `Footer` props
 */
interface IFooterProps extends ILayoutWithDirection, ILayoutWithPadding, IComponentPropsWithoutRef<typeof Component.footer> {
}
/**
 * `Footer` - A layout component designed to contain a page's footer content. Renders as a `footer` element
 * @param props `IFooterProps` used to render this `Footer`
 * @returns `Footer` component
 */
declare const Footer: React.ForwardRefExoticComponent<IFooterProps & React.RefAttributes<HTMLElement>>;

/**
 * Type to define `Header` element
 */
type IHeader = React.ElementRef<typeof Component.header>;
/**
 * Type to define `Header` props
 */
interface IHeaderProps extends ILayoutWithDirection, ILayoutWithPadding, IComponentPropsWithoutRef<typeof Component.header> {
}
/**
 * `Header` - A layout component designed to contain a page's header content. Renders as a `header` element
 * @param props `IHeaderProps` used to render this `Header`
 * @returns `Header` component
 */
declare const Header: React.ForwardRefExoticComponent<IHeaderProps & React.RefAttributes<HTMLElement>>;

/**
 * Type to define `Page` element
 */
type IPage = React.ElementRef<typeof Component.div>;
/**
 * Type to define `Page` props
 */
interface IPageProps extends ILayoutWithDirection, IComponentPropsWithoutRef<typeof Component.div> {
}
/**
 * `Page` - A `Container` designed to contain an entire page. Renders as a `div` element that fills the screen
 * @param props `IPageProps` used to render this `Page`
 * @returns `Page` component
 */
declare const Page: React.ForwardRefExoticComponent<IPageProps & React.RefAttributes<HTMLDivElement>>;

export { Content, Footer, Header, IContent, IContentProps, IFooter, IFooterProps, IHeader, IHeaderProps, IPage, IPageProps, Page };
